@@ -1,6 +1,9 @@
 import logging
 import click
 from os import environ, path
+
+from vxbase import logger
+
 from vxci import __version__, common
 from vxci.checkers import check_all
 from vxci.common import check_credentials, prepare, resume_log, notify_orchest
@@ -17,10 +20,15 @@ signal.signal(signal.SIGINT, common.reciveSignal)
 
 @click.group()
 @click.pass_context
-def cli(ctx):
+@click.option('--log_level', default="INFO",
+              help='Set the log level, default to INFO, possible values: INFO, DEBUG, WARNING, ERROR')
+@click.option('--log_file', default=None,
+              help='File where the los will be stored, default to None')
+def cli(ctx, log_level, log_file):
     # ctx.command.config = ctx.parent.command.config
     # parent = ctx.parent.params
-    _logger.info("VxCi: (ver: %d).", __version__)
+    logger.setup_logger("vxci", log_level, log_file)
+    _logger.info("VxCi: (ver: %s).", __version__)
     if not ctx.invoked_subcommand:
         click.echo(ctx.get_help())
 
@@ -288,7 +296,7 @@ def push_coverage():
     push_coverage_result()
 
 
-@click.command()
+@cli.command()
 @click.option('--ci_project_name', default=environ.get('CI_PROJECT_NAME'),
               help=("The project name that is currently being built."
                     " Env var: CI_PROJECT_NAME."))
