@@ -640,7 +640,16 @@ exclude_lines =
     # We don't really care what happens if fail
     except ImportError:
 
-    """.format(main_app=config_main_app, workdir='/tmp', exclude_var='${EXCLUDE_COVERAGE}')
+fail_under = {min_var}
+precision = {precision_var}
+
+    """.format(
+        main_app=config_main_app,
+        workdir='/tmp',
+        exclude_var='${EXCLUDE_COVERAGE}',
+        min_var='${COVERAGE_MIN-0}',
+        precision_var='${COVERAGE_PRECISION-0}',
+    )
     return coveragerc_content
 
 def show_log(log, title, config):
